import gulp from 'gulp';
import through from 'through2';
import path from 'path';
import del from 'del';
import concat from 'gulp-concat';
import rename from 'gulp-rename';
import OSS from 'ali-oss';
import fs, { chownSync } from 'fs';
import cssFormat from 'gulp-css-format';

// const ASSETS_URL = 'https://devimg.sunlands.wang';
// const ASSETS_PATH = '1114'

export default function (opts = {}) {
  const { cwd = process.cwd(), watch, entry, filename, env, ifBd } = opts;
  // gulp.task('replaceScript', () => replaceScript(cwd));
  // gulp.task('uploadFiles', ['replaceScript'], () => uploadFiles({ cwd, env, filename }));
  const run = gulp.series(cb => replaceScript(cwd, ifBd, cb), cb => uploadFiles({ cwd, ifBd, filename }, cb));
  run();

  // uploadFiles({ cwd, env, filename });
  // del(['./dist']);
  // uploadImg(cwd);
  // transformHtml(cwd);
  // transformStyle(cwd);
}

function uploadFiles({ cwd, ifBd, filename }) {
  const client = new OSS({
    region: 'oss-cn-beijing',
    accessKeyId: 'LTAIuiKdkWndO0zA',
    accessKeySecret: 'oe2VcpFF58QAJl5mhF9mqamVAtXsK2',
  });
  let bucket = 'xiaochengxu-prod';
  let ASSETS_PATH = 'html/' + filename;
  if (ifBd) {
    bucket = 'baiduxcx';
  }
  client.useBucket(bucket);

  const redFile = (cwd, basename) => {
    fs.readdir(cwd, (err, files) => {
      files.forEach(item => {
        const _path = path.join(cwd, item);
        fs.stat(_path, async (err, stats) => {
          if (stats.isDirectory()) {
            redFile(_path, item);
          } else {
            const stream = fs.createReadStream(_path);
            let clientname = `${ASSETS_PATH}/${item}`;
            if (basename) {
              clientname = `${ASSETS_PATH}/${basename}/${item}`;
            }
            const result = await client.put(clientname, stream);
            console.info(result);
          }
        });
      });
    });
  };

  redFile(cwd);
}

function replaceScript(cwd, ifBd) {
  return gulp
    .src(path.resolve(cwd, 'index.html'))
    .pipe(
      through.obj(function (file, enc, cb) {
        let contents = file.contents.toString('utf-8');
        contents = contents.replace(
          /http\:\/\/ggtf\.sunland\.org\.cn\/statistics\/interactive\.js/g,
          ifBd
            ? 'https://www.sunlands.wang/wtm.js'
            : 'https://img.sunlands.wang/wtm.js',
        );
        contents = contents.replace(
          /http\:\/\/ggtf\.sunland\.org\.cn\/statistics\/sunlandsLog\.js/g,
          ifBd
            ? 'https://b.bdstatic.com/searchbox/icms/searchbox/js/swan-1.6.0.js'
            : 'https://res.wx.qq.com/open/js/jweixin-1.3.2.js',
        );
        file.contents = new Buffer(contents);
        // file.path = file.path.replace('.html', '.wxml');
        this.push(file);
        cb();
      }),
    )
    .pipe(rename({ basename: 'home' }))
    .pipe(gulp.dest('./'));
}

async function uploadImg(cwd) {
  let bucket = 'xiaochengxu-001';
  // if (env === 'production') {
  //   bucket = 'xiaochengxu-prod';
  // }
  client.useBucket(bucket);
  const dist = path.join(cwd, 'images');
  fs.readdir(dist, async (err, files) => {
    files.forEach(async item => {
      const stream = fs.createReadStream(`${dist}/${item}`);
      const result = await client.put(`${ASSETS_PATH}/${item}`, stream);
      console.info(result);
    });
  });
}

function transformHtml(cwd) {
  gulp
    .src(path.resolve(cwd, 'index.html'))
    .pipe(
      through.obj(function (file, enc, cb) {
        const contents = file.contents.toString('utf-8');
        const body = getBody(contents);
        let result = body.replace(/(\<\/?)((body)|(div)|(section))/g, '$1view');
        result = result.replace(/\<img/g, '<image');
        result = result.replace(
          /images\/(.*)/g,
          `${ASSETS_URL}/${ASSETS_PATH}/$1`,
        );
        file.contents = new Buffer(result);
        file.path = file.path.replace('.html', '.wxml');
        this.push(file);
        cb();
      }),
    )
    .pipe(gulp.dest('./dist/'));
}

function transformStyle(cwd) {
  gulp
    .src(path.resolve(cwd, 'css', '*.css'))
    .pipe(concat('index.css'))
    .pipe(rename({ extname: '.wxss' }))
    .pipe(cssFormat({ indent: 1, hasSpace: true }))
    .pipe(
      through.obj(function (file, enc, cb) {
        let contents = file.contents.toString('utf-8');
        contents = contents.replace(
          /\.\.\/images\/(.*)/g,
          `${ASSETS_URL}/${ASSETS_PATH}/$1`,
        );
        contents = contents.replace(/\*\{([\s\S]+?)\}/g, '');
        contents = contents.replace(/-*(\d*\.*\d+)rem/g, (str, $1, $2) => {
          let num = parseFloat($1);
          num = num * 75;
          return num + 'rpx';
        });
        file.contents = new Buffer(contents);
        this.push(file);
        cb();
      }),
    )
    .pipe(gulp.dest('./dist/'));
}

function getBody(contents) {
  const body = contents.match(/\<body([\s\S]+)\<\/body\>/)[0];
  return body.replace(/\<script([\s\S]+?)\<\/script\>/g, '');
}
